@@ -447,8 +447,9 @@ class BaseKempAppliance(HttpClient, AccessInfoMixin):
                 # that makes unset interfaces inherit the previous interfaces IP.
                 for interface in interfaces:
                     if iface.addr == interface.addr:
-                        iface.addr = None
-                interfaces.append(iface)
+                        break
+                else:
+                    interfaces.append(iface)
             return interfaces
         except KempTechApiException as e:
             # If showiface does not support listing of all interfaces (possibly due to
