@@ -1687,7 +1687,7 @@ class Interface(BaseKempObject):
         "interfacetype", "additionaladdresses"
     )
 
-    def __init__(self, loadmaster_info, interface):
+    def __init__(self, loadmaster_info, interface, params=None):
         """ Interface constructor
 
         :param loadmaster_info: LoadMaster access_info
@@ -1698,6 +1698,9 @@ class Interface(BaseKempObject):
         # to work correctly when there are no IPs or CIDR set.
         self.addr = ""
         self.cidr = ""
+        self.shared = None
+        self.partner = None
+        self.populate_default_attributes(params)
         super(Interface, self).__init__(loadmaster_info)
 
     def __str__(self):
@@ -1711,7 +1714,7 @@ class Interface(BaseKempObject):
 
     @address.setter
     def address(self, value):
-        self.addr = value + "/" + self.cidr if value is not None else None
+        self.addr = "{}/{}".format(value, self.cidr) if value is not None else None
 
     @property
     def cidr(self):
@@ -1719,7 +1722,7 @@ class Interface(BaseKempObject):
 
     @cidr.setter
     def cidr(self, value):
-        self.addr = self.address + "/" + value if value is not None else None
+        self.addr = "{}/{}".format(self.address, value) if value is not None else None
 
     def save(self, update=True):
         # pylint: disable=duplicate-code
@@ -1738,11 +1741,7 @@ class Interface(BaseKempObject):
                 else:
                     raise
             else:
-                if is_successful(response):
-                    data = get_data(response)
-                    self.populate_default_attributes(data)
-                else:
-                    raise KempTechApiException(get_error_msg(response))
+                self._is_successful_or_raise(response)
 
     def stats(self):
         try:
@@ -1767,8 +1766,9 @@ class Interface(BaseKempObject):
 
         return stats
 
-    def populate_default_attributes(self, dictionary):
-        super(Interface, self).populate_default_attributes(dictionary)
+    def populate_default_attributes(self, params):
+        params = {} if params is None else params
+        super(Interface, self).populate_default_attributes(params)
 
         # Strip additional addresses into a list
         if isinstance(self.additionaladdresses, OrderedDict):
